@@ -3,7 +3,7 @@ package Specio::Constraint::AnyDoes;
 use strict;
 use warnings;
 
-our $VERSION = '0.13';
+our $VERSION = '0.14';
 
 use B ();
 use Role::Tiny::With;
@@ -24,16 +24,21 @@ with 'Specio::Constraint::Role::DoesType';
         my $self = shift;
         my $val  = shift;
 
-        return
-              '( Scalar::Util::blessed('
-            . $val
-            . ') || ( '
-            . " defined $val && ! ref $val ) ) && "
-            . $val
-            . q{->can('does')} . '&&'
-            . $val
-            . '->does('
-            . B::perlstring( $self->role ) . ')';
+        return sprintf( <<'EOF', ($val) x 4, B::perlstring( $self->role ) );
+(
+    (
+        Scalar::Util::blessed( %s )
+        ||
+        (
+            !ref( %s )
+        )
+    )
+    &&
+    %s->can('does')
+    &&
+    %s->does(%s)
+)
+EOF
     };
 
     sub _build_inline_generator {$_inline_generator}
@@ -57,7 +62,7 @@ Specio::Constraint::AnyDoes - A class for constraints which require a class name
 
 =head1 VERSION
 
-version 0.13
+version 0.14
 
 =head1 SYNOPSIS
 
