@@ -3,7 +3,7 @@ package Specio::Constraint::AnyIsa;
 use strict;
 use warnings;
 
-our $VERSION = '0.13';
+our $VERSION = '0.14';
 
 use B ();
 use Role::Tiny::With;
@@ -24,14 +24,19 @@ with 'Specio::Constraint::Role::IsaType';
         my $self = shift;
         my $val  = shift;
 
-        return
-              '( Scalar::Util::blessed('
-            . $val
-            . ') || ( '
-            . " defined $val && ! ref $val ) ) && "
-            . $val
-            . '->isa('
-            . B::perlstring( $self->class ) . ')';
+        return sprintf( <<'EOF', ($val) x 3, B::perlstring( $self->class ) );
+(
+    (
+        Scalar::Util::blessed( %s )
+        ||
+        (
+            !ref( %s )
+        )
+    )
+    &&
+    %s->isa(%s)
+)
+EOF
     };
 
     sub _build_inline_generator {$_inline_generator}
@@ -55,7 +60,7 @@ Specio::Constraint::AnyIsa - A class for constraints which require a class name
 
 =head1 VERSION
 
-version 0.13
+version 0.14
 
 =head1 SYNOPSIS
 
